var examples =
[
    [ "Polygon/Example.cpp", "Polygon_2Example_8cpp-example.html", null ],
    [ "Polygon/ranges.cpp", "Polygon_2ranges_8cpp-example.html", null ],
    [ "Polygon/polygon_algorithms.cpp", "Polygon_2polygon_algorithms_8cpp-example.html", null ],
    [ "Polygon/Polygon.cpp", "Polygon_2Polygon_8cpp-example.html", null ],
    [ "Polygon/projected_polygon.cpp", "Polygon_2projected_polygon_8cpp-example.html", null ],
    [ "Stream_support/Polygon_WKT.cpp", "Stream_support_2Polygon_WKT_8cpp-example.html", null ],
    [ "Polygon/draw_polygon.cpp", "Polygon_2draw_polygon_8cpp-example.html", null ],
    [ "Polygon/draw_polygon_with_holes.cpp", "Polygon_2draw_polygon_with_holes_8cpp-example.html", null ],
    [ "Polygon/multipolygon.cpp", "Polygon_2multipolygon_8cpp-example.html", null ],
    [ "Polygon/draw_multipolygon_with_holes.cpp", "Polygon_2draw_multipolygon_with_holes_8cpp-example.html", null ]
];